package com.mycompany.commerce.mycomponent.commands;

/*
 *-----------------------------------------------------------------
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (C) Copyright IBM Corp. 2014
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has
 * been deposited with the U.S. Copyright Office.
 *-----------------------------------------------------------------
 */

import java.io.Serializable;
import java.rmi.RemoteException;
import java.sql.SQLException;
import java.sql.Timestamp;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.ibm.commerce.base.objects.ServerJDBCHelperAccessBean;
import com.ibm.commerce.command.CommandContext;
import com.ibm.commerce.command.ControllerCommandImpl;
import com.ibm.commerce.exception.ECException;
import com.ibm.commerce.exception.ECSystemException;
import com.ibm.commerce.key.ECKeyManager;
import com.ibm.commerce.ras.ECMessage;

public class MyResourceCreateCmdImpl extends ControllerCommandImpl implements
		MyResourceCreateCmd {

	private static final String CLASSNAME = MyResourceCreateCmdImpl.class
			.getName();

	private static final String UPDATE = "INSERT INTO XMYRES (XMYRES_ID, STOREENT_ID, MEMBER_ID, FIELD1, FIELD2) VALUES (?, ?, ?, ?, ?)";

	private String TABLE_NAME_XMYRES = "XMYRES";
	private String PARAM_NAME_MY_RESOURCE_ID = "myResourceId";
	private String PARAM_NAME_FIELD1 = "field1";
	private String PARAM_NAME_FIELD2 = "field2";

	/*private Long myResourceId = null;
	private String field1 = null;
	private Timestamp field2 = null;*/
	
	private Long myResourceId;
	private String field1="";
	private Timestamp field2;

	/**
	 * Returns my resource ID.
	 * 
	 * @return My resource ID.
	 */
	@Override
	public Long getMyResourceId() {
		return myResourceId;
	}

	/**
	 * Sets field 1.
	 * 
	 * @param field1
	 *            Field 1.
	 */
	@Override
	public void setField1(String field1) {
		this.field1 = field1;
	}

	/**
	 * Sets field 2.
	 * 
	 * @param field2
	 *            Field 2.
	 */
	@Override
	public void setField2(Timestamp field2) {
		this.field2 = field2;
	}

	
	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ibm.commerce.command.AbstractECTargetableCommand#validateParameters()
	 */
	@Override
	public void validateParameters() throws ECException {
		super.validateParameters();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * com.ibm.commerce.command.AbstractECTargetableCommand#performExecute()
	 */
	@Override
	public void performExecute() throws ECException {

		final String METHODNAME = "performExecute()";
		try {

			super.performExecute();

			CommandContext commandContext = getCommandContext();
			Integer storeId = commandContext.getStoreId();
			Long userId = commandContext.getUserId();

			Long myResourceId = ECKeyManager.singleton().getNextKey(TABLE_NAME_XMYRES);
			new ServerJDBCHelperAccessBean().executeParameterizedUpdate(UPDATE,
					new Serializable[] { myResourceId, storeId, userId, field1,
							field2 });

			
			this.myResourceId = myResourceId;
		

		} catch (CreateException e) {
			throw new ECSystemException(ECMessage._ERR_CREATE_EXCEPTION,
					CLASSNAME, METHODNAME, new Object[] { e.toString() }, e);
		} catch (FinderException e) {
			throw new ECSystemException(ECMessage._ERR_FINDER_EXCEPTION,
					CLASSNAME, METHODNAME, new Object[] { e.toString() }, e);
		} catch (NamingException e) {
			throw new ECSystemException(ECMessage._ERR_NAMING_EXCEPTION,
					CLASSNAME, METHODNAME, new Object[] { e.toString() }, e);
		} catch (SQLException e) {
			throw new ECSystemException(ECMessage._ERR_SQL_EXCEPTION,
					CLASSNAME, METHODNAME, new Object[] { e.toString() }, e);
		} catch (RemoteException e) {
			throw new ECSystemException(ECMessage._ERR_REMOTE_EXCEPTION,
					CLASSNAME, METHODNAME, new Object[] { e.toString() }, e);
		}

	}

}
